///
///Name: "Energiemanager Polar"
///Das Planspiel wurde im Rahmen des Forschungsprojekt Polar entwickelt.
/// Zum Abspielen oben auf das Play-Symbol klicken (Anwenden)


///Aufbau
///Das Skript ist in 3 Teile aufgeteilt:
///1) GUI - Dieser Teil enthält Funktionen, die für die Gestaltung der GUI genutzt werden
///2) callbacks - Dieser Teil enthält die Callback-Funktionen sämtlicher interaktiver Elemente
///3) main - Der Hauptteil (z.b. Definition der Fabrik)
///
///Autor: David Hobl (David.Hobl@fir.rwth-aachen.de)


///prelude
funcprot(0);
my_path=pwd();

//Teil 1
//----------------------------------------------------------------------
////GUI-funktionen//////////////////////////////////////////////////////
//----------------------------------------------------------------------

//
//funktion um Fenster zu erstellen
//
function fig_handle = createMainWindow(axes_size, fig_name, tag_name)
    fig_handle = figure( ...
        "dockable", "off", ...
        "infobar_visible", "off", ...
        "toolbar_visible", "off", ...
        "toolbar", "none", ...
        "menubar_visible", "off", ...
        "menubar", "none", ...
        "default_axes", "off", ...
        "layout", "gridbag", ...
        "visible", "on", ...
        "immediate_drawing", "on", ...
        "background", -2, ...
        "figure_position", [0 0], ...
        "user_data", %t, ...
        "axes_size", axes_size, ...
        "figure_name", fig_name, ...
        "tag", tag_name);
endfunction

//Funktion zum erstellen der Preisachse im plot_frame
//Der Titel wird dazu genutzt die aktuelle Stunde mit einem Doppelpfeil anzuzeigen

function axes_handle=define_axes_1(plot_frame_handle)
        ax1=newaxes(plot_frame_handle);
        ax1.axes_bounds=[0,0,1.0,0.5];
        ax1.y_label.text="Preis in ct/kWh"
        ax1.y_label.foreground = 10;
        ax1.y_label.font_size = 4;
        ax1.title.text="$\mathbf{\Longleftrightarrow}$";
        ax1.title.position=[0.25,-1];
        ax1.title.font_angle=90;
        ax1.title.font_size=4;
        ax1.title.font_style=8;
        axes_handle=ax1
endfunction

//Funktion zum erstellen der Lastachse in plot_frame
function axes_handle=define_axes_2(plot_frame_handle)
        ax2=newaxes(plot_frame_handle);
        ax2.axes_bounds=[0,0.5,1.0,0.5];
        ax2.y_label.text="Last in kW"
        ax2.y_label.foreground = 10;
        ax2.y_label.font_size = 4;
        axes_handle=ax2
endfunction

// Funktion zur Gestaltung der Ziel/Ergebniszone 
function create_result_zone(result_frame)
        result_frame.layout = "gridbag";
        
//Produktionsziel
      c = createConstraints("gridbag", [1 1 3 1], [1 1], "both", "center")
      Auftrag_text = uicontrol(result_frame, ...
     "Style", "text", ...
     "String", "Leite eine Schicht (8h) und porduziere 3 MAXeKarts!", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Auftrag_text");

//tabellarische Anzeige der Laufzeit der Maschinen um das Produktionsziel zu erreichen
       c = createConstraints("gridbag", [1 2 1 1], [0.1 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(1)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(1)+"_Ziel");
       c = createConstraints("gridbag", [1 3 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(1))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_1_Ziel");
       
       
       c = createConstraints("gridbag", [2 2 1 1], [0.1 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(2)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(2)+"_Ziel");
       c = createConstraints("gridbag", [2 3 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(2))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(2)+"_Ziel");
       
       
       c = createConstraints("gridbag", [3 2 1 1], [0.1 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(3)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(3)+"_Ziel");
       c = createConstraints("gridbag", [3 3 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(3))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(3)+"_Ziel");
       
       
       c = createConstraints("gridbag", [1 4 1 1], [0.33 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(4)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(4)+"_Ziel");
       c = createConstraints("gridbag", [1 5 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(4))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(4)+"_Ziel");
       
       
       c = createConstraints("gridbag", [2 4 1 1], [0.33 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", "Leistungsm.", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(5)+"_Ziel");
       c = createConstraints("gridbag", [2 5 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(5))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(5)+"_Ziel");
       
       
      c = createConstraints("gridbag", [3 4 1 1], [0.33 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(6)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(6)+"_Ziel");
       c = createConstraints("gridbag", [3 5 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(6))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(6)+"_Ziel");
       
       
       c = createConstraints("gridbag", [1 6 1 1], [0.1 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(7)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(7)+"_Ziel");
       c = createConstraints("gridbag", [1 7 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(7))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(7)+"_Ziel");


       c = createConstraints("gridbag", [2 6 1 1], [0.1 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", "Laser", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(8)+"_Ziel");
       c = createConstraints("gridbag", [2 7 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(8))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(8)+"_Ziel");


       c = createConstraints("gridbag", [3 6 1 1], [0.05 0.4], "both", "center")
       uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Fabrik(9)(1)), ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "M_"+string(9)+"_Ziel");
       c = createConstraints("gridbag", [3 7 1 1], [0.1 0.4], "both", "center")
        uicontrol(result_frame, ...
       "Style", "text", ...
       "String", string(Auto(9))+" h   ", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "center", ...
       "constraints", c , ...
       "tag", "Auto_"+string(9)+"_Ziel");

//Anzeige des Endergebnis
     c = createConstraints("gridbag", [1 8 3 1], [1 3.5], "both", "center", [0 5], [75 0])
     Endergebnis_frame_handle = uicontrol(result_frame , ...
"style"               , "frame"                 , ...
"backgroundcolor"     , [1 1 1]                 , ...
"layout"              , "border"                , ...
"constraints"         , c);

// aesthetic area 
c1 = createConstraints("border", "right", [20 0]);
right = uicontrol(Endergebnis_frame_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c1);
c2 = createConstraints("border", "left", [20 0]);
left = uicontrol(Endergebnis_frame_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c2);

//box für Endergebnisse
b_f_results = createBorderFont("", 18);
b_l_results = createBorder("line", "navy", 2);
b_results   = createBorder("titled", b_l_results, _("Endergebnis"), "center", "top", b_f_results, "navy");
Endergebnis_frame = uicontrol(Endergebnis_frame_handle, ...
   "style", "frame", ...
   "backgroundcolor", [1 1 1], ...
   "border", b_results, ...
   "tag", "results_frame");
   Endergebnis_frame.layout = "gridbag";
   
   //Endergebnis Gesamtverbrauch
     c = createConstraints("gridbag", [1 1 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Gesamtverbrauch (kWh):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //Gesamtverbrauch wert
     c = createConstraints("gridbag", [2 1 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_Gesamtverbrauch");
  
   //Endergebnis max. Leistung
     c = createConstraints("gridbag", [1 2 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Max Leistung (kW):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //max. Leistung Wert
     c = createConstraints("gridbag", [2 2 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_MaxLeistung");
     
   //Endergebnis Arbeitspreis
     c = createConstraints("gridbag", [1 3 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Arbeitspreis (Euro):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //Arbeitspreis Wert
     c = createConstraints("gridbag", [2 3 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_Arbeitspreis");
     
   // Endergebnis Leistungspreis
      c = createConstraints("gridbag", [1 4 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Leistungspreis (Euro):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //Leistungspreis Wert
     c = createConstraints("gridbag", [2 4 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_Leistungspreis");
     
   //Endergebnis Strafe
     c = createConstraints("gridbag", [1 5 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Strafe (Euro):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //Strafe Wert
     c = createConstraints("gridbag", [2 5 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_Penalty");
     
   //Endergebnis Gesamtpreis
      c = createConstraints("gridbag", [1 6 1 1], [1 1], "both", "center", [0 5], [75 0])
     potenzielle_last_text = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "Gesamtpreis (Euro):", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c , ...
     "tag", "Endgergbnis_text");
     
   //Gesamtpreis Wert
     c = createConstraints("gridbag", [2 6 1 1], [1 1], "both", "center", [0 5], [75 0])
     last_value = uicontrol(Endergebnis_frame, ...
     "Style", "text", ...
     "String", "0", ...
     "BackgroundColor", [1 1 1], ...
     "horizontalalignment", "center", ...
     "constraints", c,  ...
     "tag", "EV_Gesamtpreis");
endfunction


// Anzeige der Maschinen einer Fabrik
function create_Maschinen(maschinen_frame)
    set(maschinen_frame, "layout", "gridbag");
    set(maschinen_frame, "layout_options", createLayoutOptions("gridbag"));
// Es werden (3x3)=neun Maschinen angezeigt
for i=1:3
    for j=1:3
        c = createConstraints("gridbag", [j i 1 1], [1 1], "both", "center")
            masch_handle = uicontrol(maschinen_frame , ...
                "style"               , "frame"                 , ...
                "backgroundcolor"     , [1 1 1]                 , ...
                "layout"              , "border"                , ...
                "constraints"         , c);
            c = createConstraints("border", "right", [20 0]);
            left = uicontrol(masch_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c);
            c = createConstraints("border", "left", [20 0]);
            right = uicontrol(masch_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c);
            b_f_masch = createBorderFont("", 18);
            b_l_masch = createBorder("line", "navy", 2);
            b_masch   = createBorder("titled", b_l_masch, string(Fabrik((i-1)*3+j)(1)), "center", "top", b_f_masch, "navy");
            masch_frame = uicontrol(masch_handle, ...
                 "style", "frame", ...
                 "backgroundcolor", [1 1 1], ...
                 "border", b_masch, ...
                 "tag", "masch_frame");
            set(masch_frame, "layout", "gridbag");
            set(masch_frame, "layout_options", createLayoutOptions("gridbag"));
           c = createConstraints("gridbag", [1 1 1 1], [1 1], "both", "center")
           masch_aus=uicontrol(masch_frame, ...
                "style", "radiobutton", ...
                "backgroundcolor", [1 1 1], ...
                "tag", "masch_"+string((i-1)*3+j)+"_aus", ...
                "string", "aus", ...
                "groupname", "masch_"+string((i-1)*3+j)+"_selection", ...
                "horizontalalignment", "left", ...
                "callback", "update_masch_"+string((i-1)*3+j),...
                "constraints", c);
                        masch_aus.value=1;
      if ((i-1)*3+j==4|(i-1)*3+j==5|(i-1)*3+j==6)//Maschinen mit standby
       c = createConstraints("gridbag", [1 2 1 1], [1 1], "both", "center")
        masch_standby=uicontrol(masch_frame, ...
        "style", "radiobutton", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "masch_"+string((i-1)*3+j)+"_standby", ...
        "string", "standby", ...
        "groupname", "masch_"+string((i-1)*3+j)+"_selection", ...
        "horizontalalignment", "left", ...
        "callback", "update_masch_"+string((i-1)*3+j),...
        "constraints", c);
       c = createConstraints("gridbag", [1 3 1 1], [1 1], "both", "center")
        masch_on=uicontrol(masch_frame, ...
        "style", "radiobutton", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "masch_"+string((i-1)*3+j)+"_on", ...
        "string", "an", ...
        "enable", "off",...
        "groupname", "masch_"+string((i-1)*3+j)+"_selection", ...
        "horizontalalignment", "left", ...
        "callback", "update_masch_"+string((i-1)*3+j),...
        "constraints", c);
      else
       c = createConstraints("gridbag", [1 3 1 1], [1 1], "both", "center")
        masch_on=uicontrol(masch_frame, ...
        "style", "radiobutton", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "masch_"+string((i-1)*3+j)+"_on", ...
        "string", "an", ...
        "groupname", "masch_"+string((i-1)*3+j)+"_selection", ...
        "horizontalalignment", "left", ...
        "callback", "update_masch_"+string((i-1)*3+j),...
        "constraints", c);
     end
       c = createConstraints("gridbag", [2 1 1 1], [1 1], "both", "center")
       masch_text_aus = uicontrol(masch_frame, ...
       "Style", "text", ...
       "String", string(Fabrik((i-1)*3+j)(2)(1))+" kW", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "left", ...
       "constraints", c , ...
       "tag", "masch_"+string((i-1)*3+j)+"_aus_text")
       if ((i-1)*3+j==4|(i-1)*3+j==5|(i-1)*3+j==6)//Maschinen mit standby
         c = createConstraints("gridbag", [2 2 1 1], [1 1], "both", "center")
         masch_text_standby = uicontrol(masch_frame, ...
         "Style", "text", ...
         "String", string(Fabrik((i-1)*3+j)(2)(2))+" kW", ...
         "BackgroundColor", [1 1 1], ...
         "horizontalalignment", "left", ...
         "constraints", c , ...
         "tag", "masch_"+string((i-1)*3+j)+"_standby_text");
       end
       c = createConstraints("gridbag", [2 3 1 1], [1 1], "both", "center")
       masch_text_on = uicontrol(masch_frame, ...
       "Style", "text", ...
       "String", string(Fabrik((i-1)*3+j)(2)(3))+" kW", ...
       "BackgroundColor", [1 1 1], ...
       "horizontalalignment", "left", ...
       "constraints", c , ...
       "tag", "masch_"+string((i-1)*3+j)+"_on_text");
    end
end

/////push buttons and highscore at the bottom of fabrik
    //start/weiterbutton
      c = createConstraints("gridbag", [1 4 1 1], [1 1], "both", "center");
      button_frame=uicontrol(maschinen_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "Sim_frame", ...
        "constraints", c);
    set(button_frame, "layout", "gridbag");
    set(button_frame, "layout_options", createLayoutOptions("gridbag"));
    c = createConstraints("gridbag", [1 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
    c = createConstraints("gridbag", [2 1 1 1], [1 0], "horizontal", "center");
    star_button = uicontrol(button_frame, ...
        "Style", "pushbutton", ...
        "String", "Runde beenden", ...
        "Fontsize", 14, ...
        "callback", "weiter_button()", ...
        "constraints", c, ...
        "tag", "weiter_button");
            c = createConstraints("gridbag", [3 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c)
    //resetbutton
    c = createConstraints("gridbag", [2 4 1 1], [1 1], "both", "center");
      button_frame=uicontrol(maschinen_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "Sim_frame", ...
        "constraints", c);
    set(button_frame, "layout", "gridbag");
    set(button_frame, "layout_options", createLayoutOptions("gridbag"));
    c = createConstraints("gridbag", [1 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
    c = createConstraints("gridbag", [2 1 1 1], [1 0], "horizontal", "center");
          clear_button = uicontrol(button_frame, ...
        "Style", "pushbutton", ...
        "String", "Neustart", ...
        "Fontsize", 14, ...
        "callback", "reset_button()", ...
        "constraints", c, ...
        "tag", "clear_button");
            c = createConstraints("gridbag", [3 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
     //highscore
       c = createConstraints("gridbag", [3 4 1 1], [1 1], "both", "center");
      button_frame=uicontrol(maschinen_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "tag", "Sim_frame", ...
        "constraints", c);
    set(button_frame, "layout", "gridbag");
    set(button_frame, "layout_options", createLayoutOptions("gridbag"));
    c = createConstraints("gridbag", [1 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
    c = createConstraints("gridbag", [2 1 1 1], [1 0], "horizontal", "center");
         highscore = uicontrol(button_frame, ...
        "Style", "text", ...
        "String", "Highscore: 100 ", ...
        "Fontsize", 14, ...
        "horizontalalignment", "center", ...
        "constraints", c, ...
        "tag", "highscore");
            c = createConstraints("gridbag", [3 1 1 1], [0.5 0], "horizontal", "center");
    esthetic = uicontrol(button_frame, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
endfunction


// Diese Funktion  initialisiert den Preis Plot am start und nach dem reset des Planspiels
function initialize_preis ()
    Durchschnittspreis=mean(Preis);
    a=length(Preis);
    sca(a1);
    plot([0,a],[Durchschnittspreis,Durchschnittspreis],"k--")
    xstring(9,Durchschnittspreis+0.1,["Durchschnittspreis"])
    plot([8,8],[0,25],"k-")
    xstring(8,Durchschnittspreis/2,["Schichtende"])
    xgrid(1, 0.3, 10)
endfunction


// Diese Funktion  initialisiert den Last Plot am Start und nach dem Reset des Planspiels
function initialize_last ()
      a=length(Preis);
      sca(a2);
      ax=sca(a2);
      plot([0,a],[Durchschnittsleistung,Durchschnittsleistung],"k--")
      xstring(9,Durchschnittsleistung+1,["Durchschnittslast"])
      plot([0,a],[Leistungsgrenze,Leistungsgrenze],"k-.")
      xstring(9,Leistungsgrenze+1,["Leistungsgrenze"])
      plot([8,8],[0,Leistungsgrenze+20],"k-")
      xstring(8,Durchschnittsleistung/2,["Schichtende"])
      xgrid(1, 0.3, 10)
      ax.title.position=[0.25,Leistungsgrenze+20+25];
endfunction

// Diese Funktion summiert die aktuelle Last aller Maschinen (Last_maschinen) und speichert sie im global array Last
function get_Last()
    global Last
    gesamtlast=0;
    for i=1:9
    gesamtlast=gesamtlast+Last_maschinen(i)
    end
    Last(LaufVariable+1)=gesamtlast;
endfunction

// Diese Funktion summiert die aktuelle Last aller Maschinen (Last_maschinen) und zeigt sie im Lastplot an
function aktuelle_Last()
    gesamtlast=0;
    for i=1:9
    gesamtlast=gesamtlast+Last_maschinen(i)
    end
          a=sca(a2);
          a.children(1).visible="off"
          plot([LaufVariable,LaufVariable+1],[gesamtlast,gesamtlast],"b-.")
          a=sca(a2);
          a.children(1).children(1).thickness=2
endfunction



//Teil 2
//----------------------------------------------------------------------
//callbacks/////////////////////////////////////////////////////////////
//----------------------------------------------------------------------

//callback für den start/weiter button
//Er wird vorallem verwendet um das Planspiel eine Runde weiter zu schalten
//Nach ablauf der SChicht (if LaufVariable==8) wird das gesamtergebnis angezeigt
function weiter_button()
       global LaufVariable
       global Arbeitspreis
       global Auto
       global Penalty
       global Prev_Last
       global Highscore
       if LaufVariable>=0
          weiter=get("weiter_button")
          weiter.String="Runde beenden";
          sca(a1);
          plot2d2([LaufVariable+3,LaufVariable+4,LaufVariable+5]',[Preis(LaufVariable+4),Preis(LaufVariable+5),Preis(LaufVariable+5)]',style=[21])
          a=sca(a1);
          a.children(1).children(1).thickness=1.2
          a.title.position=[LaufVariable+1.25,-1];
          sca(a1);
          plot([LaufVariable+1,LaufVariable+2],[Preis(LaufVariable+2),Preis(LaufVariable+2)],"r-")
          a=sca(a1);
          a.children(1).children(1).thickness=1.5
          get_Last();
          sca(a2);
          a=sca(a2);
          plot([LaufVariable,LaufVariable+1],[Last(LaufVariable+1),Last(LaufVariable+1)])
          a.children(1).children(1).thickness=1.5
          plot([LaufVariable,LaufVariable+1],[Last(LaufVariable+1),Last(LaufVariable+1)])
          a=sca(a2);
          a.children(1).children(1).thickness=1.5
          for i=1:9
              if is_standby(i)
                  masch=get(msprintf('masch_%d_on',i))
                  masch.enable="on"
              elseif ~is_standby(i)& (i==4|i==5|i==6)
                  masch=get(msprintf('masch_%d_on',i))
                  masch.enable="off"
              end
              plan=get(msprintf('Auto_%d_Ziel',i))
              if Last_on(i)
                  Auto(i)=Auto(i)-1;
                     plan.String= string(Auto(i))+" h  "
                   if Auto(i)<=0
                     name=get(msprintf('M_%d_Ziel',i))
                     name.ForegroundColor=[0 0.8 0.2]
                   end
              elseif ~Last_on(i) & i>6 & Auto(i)>0 & Prev_Last(i)
                    Penalty=Penalty+3;
              end
              name=get(msprintf('M_%d_Ziel',i))
              if (i==4|i==5|i==6) & (~is_standby(i))
                 if Auto(i)==6-LaufVariable & ~(Auto(i)==0)
                  name.ForegroundColor=[1 0.7 0]
                 elseif Auto(i)>7-LaufVariable
                  name.ForegroundColor=[1 0 0]
                 end
              else
                 if Auto(i)==7-LaufVariable
                     name.ForegroundColor=[1 0.7 0]
                 elseif Auto(i)>7-LaufVariable
                     name.ForegroundColor=[1 0 0]
                 end
              end
          end
          Prev_Last=Last_on;
          Arbeitspreis=Arbeitspreis+Last(LaufVariable+1)*Preis(LaufVariable+1)*1;
          LaufVariable=LaufVariable+1;
          aktuelle_Last()
          if LaufVariable==8
           a=sca(a1);
           a.children(1).visible="off"
           a=sca(a2);
           a.children(1).visible="off"
             zielerfuellt=%t
             for i=1:9
                 if Auto(i)<=0
                 name=get(msprintf('M_%d_Ziel',i))
                 name.ForegroundColor=[0 0.8 0.2]
                 end
                 if Auto(i)>0
                    zielerfuellt=%f; 
                 end
             end
             if zielerfuellt
                EV_Gesamtverbrauch=get("EV_Gesamtverbrauch");
                EV_MaxLeistung=get("EV_MaxLeistung");
                EV_Arbeitspreis=get("EV_Arbeitspreis");
                EV_Leistungspreis=get("EV_Leistungspreis");
                EV_Penalty=get("EV_Penalty");
                EV_Gesamtpreis=get("EV_Gesamtpreis");
                if max(Last) > Leistungsgrenze
                 Leistungspreis=10.91*max(Last)/365;
                 if max(Last)-Leistungsgrenze>10
                     Penalty=Penalty+20;
                 else
                    Penalty=Penalty+10;
                 end
                else
                 Leistungspreis=6.91*max(Last)/365;
                end
                Gesamtpreis=Arbeitspreis/100+Leistungspreis+Penalty;
                EV_Gesamtverbrauch.String=string(sum(Last));
                EV_MaxLeistung.String=string(max(Last));
                EV_Arbeitspreis.String=msprintf("%.2f",Arbeitspreis/100);
                EV_Leistungspreis.String=msprintf("%.2f",Leistungspreis);
                EV_Penalty.String=string(Penalty);
                EV_Gesamtpreis.String=msprintf("%.2f",Gesamtpreis);
                LaufVariable=-1;
                weiter.String="Schichtende";
                if Gesamtpreis < Highscore
                  Highscore=Gesamtpreis; 
                    HS=get("highscore")
                    HS.String="Highscore: "+msprintf("%.2f",Gesamtpreis)+" Euro"
                end
            else
                Ziel=get("Auftrag_text")
                Ziel.String="Ziel nicht erfüllt! 100 Euro Vertragstrafe!"
                Ziel.ForegroundColor=[1 0 0];
                Penalty=Penalty+100;
                EV_Gesamtverbrauch=get("EV_Gesamtverbrauch");
                EV_MaxLeistung=get("EV_MaxLeistung");
                EV_Arbeitspreis=get("EV_Arbeitspreis");
                EV_Leistungspreis=get("EV_Leistungspreis");
                EV_Penalty=get("EV_Penalty");
                EV_Gesamtpreis=get("EV_Gesamtpreis");
                if max(Last) > Leistungsgrenze
                 Leistungspreis=10.91*max(Last)/365;
                 if max(Last)-Leistungsgrenze>10
                     Penalty=Penalty+20;
                 else
                    Penalty=Penalty+10;
                 end
                else
                 Leistungspreis=6.91*max(Last)/365;
                end
                Gesamtpreis=Arbeitspreis/100+Leistungspreis+Penalty;
                EV_Gesamtverbrauch.String=string(sum(Last));
                EV_MaxLeistung.String=string(max(Last));
                EV_Arbeitspreis.String=msprintf("%.2f",Arbeitspreis/100);
                EV_Leistungspreis.String=msprintf("%.2f",Leistungspreis);
                EV_Penalty.String=string(Penalty);
                EV_Gesamtpreis.String=msprintf("%.2f",Gesamtpreis);
                LaufVariable=-1;
                weiter.String="Schichtende";
                if Gesamtpreis < Highscore
                  Highscore=Gesamtpreis; 
                    HS=get("highscore")
                    HS.String="Highscore: "+msprintf("%.2f",Gesamtpreis)+" Euro"
                end
            end
          end
      end
endfunction

// callback fuer den reset_button
// Er wird verwendet um das Planspiel neu zu starten.
function reset_button()
    global LaufVariable
    global Last
    global a1
    global a2
    global Arbeitspreis
    global Last
    global Auto
    global Penalty
    global Last_maschinen
    global Last_on
    global Prev_Last
    global is_standby
    Penalty=0;
    Auto=Auto_start;
    Last=0;
    curAxe = sca(a1);
    delete(curAxe);
    curAxe = sca(a2);
    delete(curAxe);
    a1=define_axes_1(plot_frame_handle);
    a2=define_axes_2(plot_frame_handle);
    Last=0;
    LaufVariable=0;
                Ziel=get("Auftrag_text")
                Ziel.String="Leite eine Schicht (8h) und porduziere 3 MAXeKarts!"
                Ziel.ForegroundColor=[0 0 0];
    for i=1:9
     Last_maschinen(i)=Fabrik(i)(2)(1)
     Last_on(i)=%f;
     Prev_Last(i)=%f;
     is_standby(i)=%f;
     ll=get(msprintf('masch_%d_aus',i));
     ll.value=1;
     plan=get(msprintf('Auto_%d_Ziel',i))
     plan.String= string(Auto(i))+" h  "
     name=get(msprintf('M_%d_Ziel',i))
     name.ForegroundColor=[0 0 0]
              if i==4|i==5|i==6
                  masch=get(msprintf('masch_%d_on',i))
                  masch.enable="off"
              end
    end
    initialize_preis();
    initialize_last();
   for j=0:2
       sca(a1);
       plot2d2([j,j+1,j+2]',[Preis(j+1),Preis(j+2),Preis(j+2)]',style=[21])
       a=sca(a1);
       a.children(1).children(1).thickness=1.2
    end
       sca(a1);
       plot([0,1],[Preis(1),Preis(1)],"r-")
       a=sca(a1);
       a.children(1).children(1).thickness=1.5
       sca(a2);
    plot([LaufVariable,LaufVariable+1],[0,0])
        aktuelle_Last()
       weiter=get("weiter_button")
       weiter.String="Runde beenden";
    Arbeitspreis=0;
    Endergebnis_value=get("Endergebnis_value")
    Endergebnis_value.String=msprintf("%.2f",Arbeitspreis/100);
    EV_Gesamtverbrauch=get("EV_Gesamtverbrauch");
    EV_MaxLeistung=get("EV_MaxLeistung");
    EV_Arbeitspreis=get("EV_Arbeitspreis");
    EV_Leistungspreis=get("EV_Leistungspreis");
    EV_Penalty=get("EV_Penalty");
    EV_Gesamtpreis=get("EV_Gesamtpreis");
    EV_Gesamtverbrauch.String=string(0);
    EV_MaxLeistung.String=string(0);
    EV_Arbeitspreis.String=string(0);
    EV_Leistungspreis.String=string(0);
    EV_Penalty.String=string(0);
    EV_Gesamtpreis.String=string(0);
endfunction

//callback für update_masch_i , i=1..9;
//Für alle 9 Maschinen der Fabrik gibt es ein update callback das Aufgerufen wird wenn eine Maschineneinstellung geändert wird

function update_masch_1()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_1_aus" then
        Last_maschinen(1)=Fabrik(1)(2)(1);
        Last_on(1)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_1_standby" then
        Last_maschinen(1)=Fabrik(1)(2)(2);
        Last_on(1)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_1_on" then
        Last_maschinen(1)=Fabrik(1)(2)(3);
        Last_on(1)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_2()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_2_aus" then
        Last_maschinen(2)=Fabrik(2)(2)(1);
        Last_on(2)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_2_standby" then
        Last_maschinen(2)=Fabrik(2)(2)(2);
        Last_on(2)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_2_on" then
        Last_maschinen(2)=Fabrik(2)(2)(3);
        Last_on(2)=%t
        aktuelle_Last()
    end
endfunction
//////////////////////////////////////////
function update_masch_3()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_3_aus" then
        Last_maschinen(3)=Fabrik(3)(2)(1);
        Last_on(3)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_3_standby" then
        Last_maschinen(3)=Fabrik(3)(2)(2);
        Last_on(3)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_3_on" then
        Last_maschinen(3)=Fabrik(3)(2)(3);
        Last_on(3)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_4()
    global Last_maschinen
    global Last_on
    global is_standby
    if get(gcbo, "tag") == "masch_4_aus" then
        Last_maschinen(4)=Fabrik(4)(2)(1);
        Last_on(4)=%f
        is_standby(4)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_4_standby" then
        Last_maschinen(4)=Fabrik(4)(2)(2);
        Last_on(4)=%f
        is_standby(4)=%t
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_4_on" then
        Last_maschinen(4)=Fabrik(4)(2)(3);
        Last_on(4)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_5()
    global Last_maschinen
    global Last_on
    global is_standby
    if get(gcbo, "tag") == "masch_5_aus" then
        Last_maschinen(5)=Fabrik(5)(2)(1);
        Last_on(5)=%f
        is_standby(5)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_5_standby" then
        Last_maschinen(5)=Fabrik(5)(2)(2);
        Last_on(5)=%f
        is_standby(5)=%t
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_5_on" then
        Last_maschinen(5)=Fabrik(5)(2)(3);
        Last_on(5)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_6()
    global Last_maschinen
    global Last_on
    global is_standby
    if get(gcbo, "tag") == "masch_6_aus" then
        Last_maschinen(6)=Fabrik(6)(2)(1);
        Last_on(6)=%f
        is_standby(6)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_6_standby" then
        Last_maschinen(6)=Fabrik(6)(2)(2);
        Last_on(6)=%f
        is_standby(6)=%t
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_6_on" then
        Last_maschinen(6)=Fabrik(6)(2)(3);
        Last_on(6)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_7()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_7_aus" then
        Last_maschinen(7)=Fabrik(7)(2)(1);
        Last_on(7)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_7_standby" then
        Last_maschinen(7)=Fabrik(7)(2)(2);
        Last_on(7)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_7_on" then
        Last_maschinen(7)=Fabrik(7)(2)(3);
        Last_on(7)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_8()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_8_aus" then
        Last_maschinen(8)=Fabrik(8)(2)(1);
        Last_on(8)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_8_standby" then
        Last_maschinen(8)=Fabrik(8)(2)(2);
        Last_on(8)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_8_on" then
        Last_maschinen(8)=Fabrik(8)(2)(3);
        Last_on(8)=%t
        aktuelle_Last()
    end
endfunction
function update_masch_9()
    global Last_maschinen
    global Last_on
    if get(gcbo, "tag") == "masch_9_aus" then
        Last_maschinen(9)=Fabrik(9)(2)(1);
        Last_on(9)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_9_standby" then
        Last_maschinen(9)=Fabrik(9)(2)(2);
        Last_on(9)=%f
        aktuelle_Last()
    elseif get(gcbo, "tag") == "masch_9_on" then
        Last_maschinen(9)=Fabrik(9)(2)(3);
        Last_on(9)=%t
        aktuelle_Last()
    end
endfunction


//Teil 3
//----------------------------------------------------------------------
//main-body/////////////////////////////////////////////////////////////
//----------------------------------------------------------------------

//array mit dem flexiblen Preissignal
   global Preis
   Preis=[18.1,21.1,20.1,16.1,11.1,7.1,15.1,18.1,17.1,19.1,21.1,20.1];
   
//Das Porduktionsziel wird in dem array Auto gespeichert
//Es gibt an wie lange jede der neun Maschinen laufen muss damit ein Auto gebaut werden kann
   global Auto
   Auto_start=[2,3,5,5,1,2,2,4,1];
   Auto=Auto_start;


//Definition der Fabrik
//Datatype: Liste von Listen
//Die Fabrik enthält neun Maschinen, eine Maschine ist eine Liste aus ("Name", [Leistung_aus,Leistung_standby,Leistung_an])
   Fabrik= list(list("Stapler",[0,0.01,10]),list("Kompressor",[0,0.02,8]),list("Kühlung/Heizung",[0,0.005,20]),list("Werkstatt",[0,0.12,12]),list("Leistungsmessstand",[0,0.04,34]),list("Absauganlage",[0,0.01,3]),list("Ladestation",[0,0.008,2]),list("Laserschneidemaschine",[0,0.022,30]),list("Punktschweißzange",[0,0.005,9]));
//Berechnung der Durchschnittsleistung
Durchschnittsleistung=0;
Gesamtenergie=0;
   for i=1:9 
       Gesamtenergie=Gesamtenergie+Auto(i)*Fabrik(i)(2)(3);
   end

Durchschnittsleistung=Gesamtenergie/8; //8 h dauert eine Schicht
//Definition einer Leistungsgrenze
Leistungsgrenze=70;


//create a figure
clf();
my_fig_handle=createMainWindow([1200 ,800],"Energiemanager Polar", "NNL");


//create frame for plots
c = createConstraints("gridbag", [1 1 1 1], [1 1], "both");
c.grid = [1 1 2 2]
c.weight = [1 1]
plot_frame_handle = uicontrol(my_fig_handle , ...
"style"               , "frame"                     , ...
"backgroundcolor"     , [1 1 1]                     , ...
"constraints"         , c);

//create new axes in plotframe
global a1
global a2
a1=define_axes_1(plot_frame_handle);
a2=define_axes_2(plot_frame_handle);


//create a frame for results (in figure)
c.grid = [3 1 1 1]
c.weight = [0.2 1]
result_frame_handle = uicontrol(my_fig_handle , ...
"style"               , "frame"                 , ...
"backgroundcolor"     , [1 1 1]                 , ...
"layout"              , "border"                , ...
"constraints"         , c);

// create an aesthetic area in result zone
c1 = createConstraints("border", "right", [20 0]);
left = uicontrol(result_frame_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c1);


//Border for the results
b_f_results = createBorderFont("", 18);
b_l_results = createBorder("line", "navy", 2);
b_results   = createBorder("titled", b_l_results, _("Ziel"), "center", "top", b_f_results, "navy");

//create the result frame with borderes
results_frame = uicontrol(result_frame_handle, ...
   "style", "frame", ...
   "backgroundcolor", [1 1 1], ...
   "border", b_results, ...
   "tag", "results_frame");

//create the result zone
create_result_zone(results_frame);


//frame for interactive area (in figure)
c.grid = [1 3 3 1]
c.weight = [1 0.1]
param_frame_handle = uicontrol(my_fig_handle , ...
"style"               , "frame"                , ...
"backgroundcolor"     , [1 1 1]                , ...
"layout"              , "border"               , ...
"constraints"         , c);

// create an aesthetic area in paramzone zone
c2 = createConstraints("border", "right", [20 0]);
left = uicontrol(param_frame_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c2);
c2 = createConstraints("border", "left", [20 0]);
right = uicontrol(param_frame_handle, "style", "frame", "backgroundcolor", [1 1 1], "constraints", c2);

//Border for the scenario selection
b_f_simuParams = createBorderFont("", 18);
b_l_simuParams = createBorder("line", "navy", 2);
b_simuParams   = createBorder("titled", b_l_simuParams, _("Demo Fabrik Aachen - am Cluster Logistik"), "center", "top", b_f_simuParams, "navy");

//create the scenario frame with borders
param_frame = uicontrol(param_frame_handle, ...
   "style", "frame", ...
   "backgroundcolor", [1 1 1], ...
   "border", b_simuParams, ...
   "tag", "param_frame");
   
   //create a Maschinen_frame in the paramter frame
    set(param_frame, "layout", "gridbag");
    set(param_frame, "layout_options", createLayoutOptions("gridbag"));
    c = createConstraints("gridbag", [1 1 1 1], [1 1],"both");
    maschinen_frame =uicontrol(param_frame,...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
   
   create_Maschinen(maschinen_frame);
//create a frame for logos (in figure)
c.grid = [4 1 1 3]
c.weight = [0.1 1]
logo_frame_handle = uicontrol(my_fig_handle , ...
"style"               , "frame"                 , ...
"backgroundcolor"     , [1 1 1]                 , ...
"constraints"         , c);
    set(logo_frame_handle, "layout", "gridbag");
    set(logo_frame_handle, "layout_options", createLayoutOptions("gridbag"));
   c = createConstraints("gridbag", [1 1 2 1], [1 0.4], "horizontal", "center");
    esthetic = uicontrol(logo_frame_handle, ...
        "style", "frame", ...
        "backgroundcolor", [1 1 1], ...
        "constraints", c);
            c = createConstraints("gridbag", [1 2 2 1], [1 0.2], "horizontal", "center");
    esthetic = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/Planspiel_2.png",...
        "constraints", c, ...
        "horizontalalignment", "center", ...
        "value", [1 1],...
        "tag", "polar_logo");
            c = createConstraints("gridbag", [1 3 2 1], [1 0.001], "horizontal", "center");
    esthetic = uicontrol(logo_frame_handle, ...
        "style", "text", ...
        "String", " ", ...
        "FontSize", 24, ...
        "backgroundcolor", [1 1 1], ...
        "horizontalalignment", "center", ...
        "verticalalignment", "top", ...
        "constraints", c);
       c = createConstraints("gridbag", [1 4 2 1], [1 1], "horizontal", "center");
      polar_logo = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/Polar_Logo_4.png",...
        "constraints", c, ...
        "horizontalalignment", "center", ...
        "value", [1 1],...
        "tag", "polar_logo");
         c = createConstraints("gridbag", [1 5 2 1], [1 1], "horizontal", "center");
      polar_logo = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/BMBF_Foerderung_3.jpg",...
        "constraints", c, ...
        "horizontalalignment", "center", ...
        "value", [1 1],...
        "tag", "polar_logo");
       c = createConstraints("gridbag", [1 6 2 1], [1 1], "horizontal", "center");
       polar_logo = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/pt.dlr_logo_2.jpg",...
        "constraints", c, ...
        "horizontalalignment", "center", ...
        "value", [1 1],...
        "tag", "polar_logo");
       c = createConstraints("gridbag", [1 7 2 1], [1 1], "horizontal", "center");
       polar_logo = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/FIR_logo_2.jpg",...
        "constraints", c, ...
        "horizontalalignment", "center", ...
        "value", [1 1],...
        "tag", "polar_logo");
       c = createConstraints("gridbag", [1 8 1 1], [0.1 0.2], "horizontal", "center");
       polar_logo = uicontrol(logo_frame_handle, ...
        "style", "image", ...
        "backgroundcolor", [1 1 1], ...
        "String", my_path+"/Copyright.png",...
        "constraints", c, ...
        "horizontalalignment", "right", ...
        "value", [1 1],...
        "tag", "polar_logo");
          c = createConstraints("gridbag", [2 8 1 1], [0.1 0.2], "horizontal", "center");
        uicontrol(logo_frame_handle, ...
        "style", "text", ...
        "String", "Version 1.0", ...
        "FontSize", 16, ...
        "backgroundcolor", [1 1 1], ...
        "horizontalalignment", "left", ...
        "verticalalignment", "top", ...
        "constraints", c);
// aesthetic area at the bottom
c.grid = [1 4 3 1]
c.weight = [1 0.05]
 uicontrol(my_fig_handle , ...
"style"               , "frame"                 , ...
"backgroundcolor"     , [1 1 1]                 , ...
"constraints"         , c);

//Globale Variablen:
//array in dem die aktuelle Last der einzelnen Maschinen gespeichert wird
   global Last_maschinen   
   for i=1:9
    Last_maschinen(i)=Fabrik(i)(2)(1)
   end
//array in dem gespeichert wird welche Maschine an ist
   global Last_on
   for i=1:9
    Last_on(i)=%f
   end
//Laufvariable um die Runden zu zählen
   global LaufVariable
   LaufVariable=0;
//array der für jede Runde die gesamtlast speichert
   global Last
   Last=0;
//Variable für den gesamt Arbeitspreis einer Schicht
   global Arbeitspreis
   Arbeitspreis=0;
//Variable für die gesamt Strafe einer Schicht
   global Penalty
   Penalty=0
//wie Last_on nur von der vorherigen stunde
   global Prev_Last
   for i=1:9
    Prev_Last(i)=%f
   end
//Variable in der der Maschinenverlauf gespeichert wird (nicht benutzt)
//   global log_data
//   log_data=0;
//Variable für den Highscore
   global Highscore
   Highscore=100;
//array in dem gespeichert wird ob eine Maschine auf stanby geschaltet ist
   global is_standby
   for i=1:9
    is_standby(i)=%f
   end

//konfiguration der Start GUI
   initialize_preis();
   initialize_last();
   for j=0:2
       sca(a1);
       plot2d2([j,j+1,j+2]',[Preis(j+1),Preis(j+2),Preis(j+2)]',style=[21])
       a=sca(a1);
       a.children(1).children(1).thickness=1.2
    end
    sca(a1);
    plot([0,1],[Preis(1),Preis(1)],"r-")
    a=sca(a1);
    a.children(1).children(1).thickness=1.5
    sca(a2);
    plot([LaufVariable,LaufVariable+1],[0,0])
    aktuelle_Last()
